summaryrefslogtreecommitdiff
path: root/capture_ui_utils.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2010-03-04 01:12:04 +0000
committerGuy Harris <guy@alum.mit.edu>2010-03-04 01:12:04 +0000
commit167ab3a98c4583344f8b95d81b079b7a5df7e5ff (patch)
treec2af1e714cc510427cdd87a9b63979038cfc40ac /capture_ui_utils.c
parent98d800bae8939f6edaf4aa54f02787148da48c0f (diff)
downloadwireshark-167ab3a98c4583344f8b95d81b079b7a5df7e5ff.tar.gz
In Wireshark and TShark, run dumpcap to get interface lists and lists of
link-layer header types for interfaces; if special privileges are necessary to open capture devices, Wireshark and TShark shouldn't have those privileges, but dumpcap should. svn path=/trunk/; revision=32104
Diffstat (limited to 'capture_ui_utils.c')
-rw-r--r--capture_ui_utils.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/capture_ui_utils.c b/capture_ui_utils.c
index c975aa6df5..ffff697eda 100644
--- a/capture_ui_utils.c
+++ b/capture_ui_utils.c
@@ -34,7 +34,7 @@
#include <glib.h>
#include <epan/prefs.h>
-#include "capture-pcap-util.h"
+#include "capture_ifinfo.h"
#include "capture_ui_utils.h"
/*
@@ -130,12 +130,12 @@ capture_dev_user_linktype_find(const gchar *if_name)
/*
* Return as descriptive a name for an interface as we can get.
* If the user has specified a comment, use that. Otherwise,
- * if get_interface_list() supplies a description, use that,
+ * if capture_interface_list() supplies a description, use that,
* otherwise use the interface name.
*
* The result must be g_free()'d when you're done with it.
*
* Note: given that this calls get_interface_list(), which attempts to
* open all adapters it finds in order to check whether they can be
* captured on, this is an expensive routine to call, so don't call it
* frequently.
@@ -158,7 +158,7 @@ get_interface_descriptive_name(const char *if_name)
/* No, we don't have a user-supplied description; did we get
one from the OS or libpcap? */
descr = NULL;
- if_list = get_interface_list(&err, NULL);
+ if_list = capture_interface_list(&err, NULL);
if (if_list != NULL && if_name != NULL) {
if_entry = if_list;
do {
@@ -130,12 +130,12 @@ capture_dev_user_linktype_find(const gchar *if_name)
* The result must be g_free()'d when you're done with it.
*
- * Note: given that this calls get_interface_list(), which attempts to
+ * Note: given that this calls capture_interface_list(), which attempts to
* open all adapters it finds in order to check whether they can be
* captured on, this is an expensive routine to call, so don't call it